@@ -4,8 +4,7 @@ import pkg_resources
 
 pkg_resources.declare_namespace(__name__)
 
-VERSION = (0, 2, 5)
-
+VERSION = (0, 2, 6)
 __version__ = ".".join(map(str, VERSION))
 __status__ = "Development"
 __description__ = u"Open Source Content Management Platform - CMS for the "
@@ -14,6 +13,6 @@ u"high-traffic, using the Django Framework."
 
 __author__ = u"Thiago Avelino"
 __credits__ = ['Bruno Rocha']
-__email__ = u"opps-developers@googlegroups.com"
-__license__ = u"MIT License"
-__copyright__ = u"Copyright 2013, Opps Project"
+__email__ = u"thiago@avelino.xxx"
+__license__ = u"MIT"
+__copyright__ = u"Copyright 2014, Thiago Avelino"
