@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 import operator
 
@@ -21,6 +20,7 @@ from opps.core.tags.models import Tagged
 from opps.db.models.fields import JSONField
 from opps.boxes.models import BaseBox
 
+from .managers import ContainerManager
 from .signals import shorturl_generate, delete_container
 from .tasks import check_mirror_channel, check_mirror_site
 
@@ -66,6 +66,8 @@ class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
     json = JSONField(_(u"Customized"),
                      null=True, blank=True)
 
+    objects = ContainerManager()
+
     def __unicode__(self):
         return u"{}".format(self.get_absolute_url())
 
@@ -81,7 +83,7 @@ class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
         ordering = ['-date_available']
         verbose_name = _(u'Container')
         verbose_name_plural = _(u'Containers')
-        unique_together = ("site", "channel_long_slug", "slug")
+        unique_together = ("site", "channel", "slug")
 
     def save(self, *args, **kwargs):
         if not self.channel_name:
@@ -110,6 +112,14 @@ class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
             return u"/{}.html".format(self.slug)
         return u"/{}/{}.html".format(self.channel_long_slug, self.slug)
 
+    @classmethod
+    def get_children_models(cls):
+        children = models.get_models()
+        return [model for model in children
+                if (model is not None and
+                    issubclass(model, cls) and
+                    model is not cls)]
+
     def get_thumb(self):
         return self.main_image
 
@@ -358,6 +368,12 @@ class ContainerBox(BaseBox):
         self.local_cache['ordered_box_containers'] = qs
         return qs
 
+    def get_containers_queryset(self):
+        if self.queryset:
+            return self.queryset.get_queryset()
+        else:
+            return self.ordered_containers()
+
     def get_queryset(self, exclude_ids=None, use_local_cache=True):
         cached = self.local_cache.get('get_queryset')
         if use_local_cache and cached:
