@@ -49,6 +49,71 @@ def _delete_cookie(self, key, path='/', domain=None):
         pass
 
 
+IGNORE_AGENTS = getattr(settings, 'OPPS_MOBILE_IGNORE_USER_AGENTS', [])
+
+USER_AGENTS_TEST_MATCH = (
+    "w3c ", "acs-", "alav", "alca", "amoi", "audi",
+    "avan", "benq", "bird", "blac", "blaz", "brew",
+    "cell", "cldc", "cmd-", "dang", "doco", "eric",
+    "hipt", "inno", "ipaq", "java", "jigs", "kddi",
+    "keji", "leno", "lg-c", "lg-d", "lg-g", "lge-",
+    "maui", "maxo", "midp", "mits", "mmef", "mobi",
+    "mot-", "moto", "mwbp", "nec-", "newt", "noki",
+    "xda", "palm", "pana", "pant", "phil", "play",
+    "port", "prox", "qwap", "sage", "sams", "sany",
+    "sch-", "sec-", "send", "seri", "sgh-", "shar",
+    "sie-", "siem", "smal", "smar", "sony", "sph-",
+    "symb", "t-mo", "teli", "tim-", "tosh", "tsm-",
+    "upg1", "upsi", "vk-v", "voda", "wap-", "wapa",
+    "wapi", "wapp", "wapr", "webc", "winw", "winw",
+    "xda-",)
+
+USER_AGENTS_TEST_SEARCH = u"(?:%s)" % u'|'.join((
+    'up.browser', 'up.link', 'mmp', 'symbian', 'smartphone', 'midp',
+    'wap', 'phone', 'windows ce', 'pda', 'mobile', 'mini', 'palm',
+    'netfront', 'opera mobi',))
+
+USER_AGENTS_EXCEPTION_SEARCH = u"(?:%s)" % u'|'.join(('ipad',))
+
+HTTP_ACCEPT_REGEX = re.compile("application/vnd\.wap\.xhtml\+xml",
+                               re.IGNORECASE)
+
+
+def is_mobile_agent(request):
+    user_agents_test_match = r'^(?:%s)' % '|'.join(
+        USER_AGENTS_TEST_MATCH)
+    user_agents_test_match_regex = re.compile(
+        user_agents_test_match, re.IGNORECASE)
+    user_agents_test_search_regex = re.compile(
+        USER_AGENTS_TEST_SEARCH, re.IGNORECASE)
+    user_agents_exception_search_regex = re.compile(
+        USER_AGENTS_EXCEPTION_SEARCH, re.IGNORECASE)
+
+    is_mobile = False
+
+    if 'HTTP_USER_AGENT' in request.META:
+        user_agent = request.META['HTTP_USER_AGENT']
+
+        if user_agents_test_search_regex.search(user_agent) and \
+           not user_agents_exception_search_regex.search(user_agent):
+            is_mobile = True
+        else:
+            if 'HTTP_ACCEPT' in request.META:
+                http_accept = request.META['HTTP_ACCEPT']
+                if HTTP_ACCEPT_REGEX.search(http_accept):
+                    is_mobile = True
+
+        if not is_mobile:
+            if user_agents_test_match_regex.match(user_agent):
+                is_mobile = True
+
+        # Check for ignore user agents
+        if IGNORE_AGENTS and user_agent in IGNORE_AGENTS:
+            is_mobile = False
+
+    return is_mobile
+
+
 class MobileDetectionMiddleware(object):
     u"""Used django-mobile core
 
@@ -56,68 +121,8 @@ class MobileDetectionMiddleware(object):
     3226e5393033115c8bf/django_mobile/middleware.py
     """
 
-    IGNORE_AGENTS = getattr(settings, 'OPPS_MOBILE_IGNORE_USER_AGENTS', [])
-
-    user_agents_test_match = (
-        "w3c ", "acs-", "alav", "alca", "amoi", "audi",
-        "avan", "benq", "bird", "blac", "blaz", "brew",
-        "cell", "cldc", "cmd-", "dang", "doco", "eric",
-        "hipt", "inno", "ipaq", "java", "jigs", "kddi",
-        "keji", "leno", "lg-c", "lg-d", "lg-g", "lge-",
-        "maui", "maxo", "midp", "mits", "mmef", "mobi",
-        "mot-", "moto", "mwbp", "nec-", "newt", "noki",
-        "xda", "palm", "pana", "pant", "phil", "play",
-        "port", "prox", "qwap", "sage", "sams", "sany",
-        "sch-", "sec-", "send", "seri", "sgh-", "shar",
-        "sie-", "siem", "smal", "smar", "sony", "sph-",
-        "symb", "t-mo", "teli", "tim-", "tosh", "tsm-",
-        "upg1", "upsi", "vk-v", "voda", "wap-", "wapa",
-        "wapi", "wapp", "wapr", "webc", "winw", "winw",
-        "xda-",)
-
-    user_agents_test_search = u"(?:%s)" % u'|'.join((
-        'up.browser', 'up.link', 'mmp', 'symbian', 'smartphone', 'midp',
-        'wap', 'phone', 'windows ce', 'pda', 'mobile', 'mini', 'palm',
-        'netfront', 'opera mobi',))
-
-    user_agents_exception_search = u"(?:%s)" % u'|'.join(('ipad',))
-
-    http_accept_regex = re.compile("application/vnd\.wap\.xhtml\+xml",
-                                   re.IGNORECASE)
-
-    def __init__(self):
-        user_agents_test_match = r'^(?:%s)' % '|'.join(
-            self.user_agents_test_match)
-        self.user_agents_test_match_regex = re.compile(
-            user_agents_test_match, re.IGNORECASE)
-        self.user_agents_test_search_regex = re.compile(
-            self.user_agents_test_search, re.IGNORECASE)
-        self.user_agents_exception_search_regex = re.compile(
-            self.user_agents_exception_search, re.IGNORECASE)
-
     def process_request(self, request):
-        is_mobile = False
-
-        if 'HTTP_USER_AGENT' in request.META:
-            user_agent = request.META['HTTP_USER_AGENT']
-
-            if self.user_agents_test_search_regex.search(user_agent) and \
-               not self.user_agents_exception_search_regex.search(user_agent):
-                is_mobile = True
-            else:
-                if 'HTTP_ACCEPT' in request.META:
-                    http_accept = request.META['HTTP_ACCEPT']
-                    if self.http_accept_regex.search(http_accept):
-                        is_mobile = True
-
-            if not is_mobile:
-                if self.user_agents_test_match_regex.match(user_agent):
-                    is_mobile = True
-
-            # Check for ignore user agents
-            if self.IGNORE_AGENTS and user_agent in self.IGNORE_AGENTS:
-                is_mobile = False
-
+        is_mobile = is_mobile_agent(request)
         request.is_mobile = is_mobile
         THREAD_LOCALS.template_dirs = settings.TEMPLATE_DIRS_WEB
 
@@ -155,20 +160,27 @@ class MobileRedirectMiddleware(object):
         template_mode = request.GET.get('template_mode', None)
         THREAD_LOCALS.template_dirs = settings.TEMPLATE_DIRS_WEB
 
-        is_mobile_domain = domain == mobile_domain
+        if hasattr(request, "is_mobile"):
+            agent_is_mobile = request.is_mobile
+        else:
+            agent_is_mobile = is_mobile_agent(request)
+
+        domain_is_mobile = domain == mobile_domain
+
+        request_is_mobile = agent_is_mobile and domain_is_mobile
 
         if not template_mode and not current_cookie:
-            if is_mobile_domain:
+            if domain_is_mobile:
                 template_mode = u'mobile'
             else:
                 return
 
-        if is_mobile_domain and template_mode == u'desktop':
+        if request_is_mobile and template_mode == u'desktop':
             prot = settings.OPPS_PROTOCOL_WEB
             web_domain = settings.OPPS_DOMAIN_WEB
             url = u"{}://{}/?template_mode=desktop".format(prot, web_domain)
             return HttpResponseRedirect(url)
-        elif not is_mobile_domain and template_mode == u'mobile':
+        elif not request_is_mobile and template_mode == u'mobile':
             prot = settings.OPPS_PROTOCOL_MOBILE
             url = u"{}://{}/?template_mode=mobile".format(prot, mobile_domain)
 
