@@ -7,18 +7,24 @@ from redis import Redis as RedisClient
 
 
 class Redis:
-    def __init__(self, key_prefix, key_sufix):
+    def __init__(self, key_prefix, key_sufix, db=0):
         self.key_prefix = key_prefix
         self.key_sufix = key_sufix
         self.host = settings.OPPS_DB_HOST
         self.port = settings.OPPS_DB_PORT
-        self.db = 0
+        self.db = db
 
         pool = ConnectionPool(host=self.host,
                               port=self.port,
                               db=self.db)
         self.conn = RedisClient(connection_pool=pool)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, tb):
+        self.close()
+
     def object(self):
         return self.conn
 
